| ndat | R Documentation |
This is a helper function, which extracts the number of data points given an INLA object
ndat(inla.object)
inla.object |
character string, the name of the INLA object fitted in |
numeric, the number of observations in the dataset used for fitting the model the result of which is given by inla.object.
inla
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.