| refit_inla | R Documentation |
This function takes the INLA object from the base model as input and fits weighted INLA models with weights w = 1 - δ and w = 1 + δ.
refit_inla(inla.object.base, delta)
inla.object.base |
character string, the name of the INLA object fitted in |
delta |
numeric, numerical differentiation step, the weighting factor w = 1 \pm δ, the default value is 0.01. |
To access the weights (w) used in INLA fit use inla.object.base\$.args\$weights. The function refit_inla modifies the original model given by inla.object.base, once with w = 1-δ and then with w = 1-δ and fits the modified models again in INLA.
list composed of two INLA objects
Read more details regarding the weights argument in inla.
inla
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.